@@ -34,12 +34,10 @@
 
 #include <libical/ical.h>
 
-#include <libekolab/kolab-types.h>
 #include <libekolab/kolab-mail-access.h>
 #include <libekolab/kolab-settings-handler.h>
 #include <libekolab/kolab-mail-handle.h>
 #include <libekolabutil/kolab-util-http.h>
-#include <libekolabutil/kolab-http-job.h>
 #include <libekolabutil/kolab-util-glib.h>
 #include <libekolabutil/kolab-util-camel.h>
 #include <libekolabutil/kolab-util-cal-freebusy.h>
@@ -565,7 +563,7 @@ e_cal_backend_kolab_get_free_busy (ECalBackendSync *backend,
 				error = NULL;
 				internal_state = FALSE;
 			}
-			kolab_http_job_free (job);
+			kolab_util_http_job_free (job);
 		}
 		if (ecalcomp == NULL) {
 			/* this is not an error, but there's no F/B
@@ -607,7 +605,7 @@ e_cal_backend_kolab_create_object (ECalBackendSync *backend,
                                    GCancellable *cancellable,
                                    const gchar *calobj,
                                    gchar **uid,
-                                   icalcomponent **new_component,
+                                   ECalComponent **new_component,
                                    GError **err)
 {
 	ECalBackendKolab *self = E_CAL_BACKEND_KOLAB (backend);
@@ -617,7 +615,7 @@ e_cal_backend_kolab_create_object (ECalBackendSync *backend,
 	(void)cancellable; /* FIXME */ /* cancellable may be NULL */
 	(void)calobj; /* FIXME */
 	(void)uid; /* FIXME */
-	(void)new_component; /* FIXME */ /* must be NULL? */
+	g_return_if_fail (new_component == NULL || *new_component == NULL);
 	g_return_if_fail (err == NULL || *err == NULL);
 
 	(void)self;
@@ -728,8 +726,8 @@ e_cal_backend_kolab_modify_object (ECalBackendSync *backend,
                                    GCancellable *cancellable,
                                    const gchar *calobj,
                                    CalObjModType mod,
-                                   icalcomponent **old_component,
-                                   icalcomponent **new_component,
+                                   ECalComponent **old_component,
+                                   ECalComponent **new_component,
                                    GError **err)
 {
 	ECalBackendKolab *self = E_CAL_BACKEND_KOLAB (backend);
@@ -739,8 +737,8 @@ e_cal_backend_kolab_modify_object (ECalBackendSync *backend,
 	(void)cancellable; /* FIXME */ /* cancellable may be NULL */
 	(void)calobj; /* FIXME */
 	(void)mod; /* FIXME */
-	(void)old_component; /* FIXME */ /* must not be NULL? */
-	(void)new_component; /* FIXME */ /* must be NULL? */
+	g_return_if_fail (old_component == NULL || *old_component == NULL); /* FIXME */
+	g_return_if_fail (new_component == NULL || *new_component == NULL); /* FIXME */
 	g_return_if_fail (err == NULL || *err == NULL);
 
 	(void)self;
@@ -920,8 +918,8 @@ e_cal_backend_kolab_remove_object (ECalBackendSync *backend,
                                    const gchar *uid,
                                    const gchar *rid,
                                    CalObjModType mod,
-                                   icalcomponent **old_component,
-                                   icalcomponent **new_component,
+                                   ECalComponent **old_component,
+                                   ECalComponent **new_component,
                                    GError **err)
 {
 	ECalBackendKolab *self = E_CAL_BACKEND_KOLAB (backend);
@@ -932,8 +930,8 @@ e_cal_backend_kolab_remove_object (ECalBackendSync *backend,
 	(void)uid; /* FIXME */
 	(void)rid; /* FIXME */ /* may be NULL? */
 	(void)mod; /* FIXME */
-	(void)old_component; /* FIXME */ /* must not be NULL? */
-	(void)new_component; /* FIXME */ /* must be NULL? */
+	g_return_if_fail (old_component == NULL || *old_component == NULL); /* FIXME */
+	g_return_if_fail (new_component == NULL || *new_component == NULL); /* FIXME */
 	g_return_if_fail (err == NULL || *err == NULL);
 
 	(void)self;
