@@ -28,9 +28,6 @@
 #include <libecal/e-cal.h>
 
 #include <libekolabutil/camel-system-headers.h>
-#include <libekolabutil/kolab-util-http.h>
-#include <libekolabutil/kolab-http-job.h>
-#include <libekolabutil/kolab-util-types.h>
 #include <libekolab/kolab-settings-handler.h>
 #include <libekolab/kolab-mail-access.h>
 
@@ -39,7 +36,7 @@
 /*----------------------------------------------------------------------------*/
 /* internal statics */
 
-static KolabHttpJob*
+static KolabUtilHttpJob*
 kolab_util_calendar_create_http_request (KolabSettingsHandler *ksettings,
                                          const gchar *path,
                                          GError **error)
@@ -50,7 +47,7 @@ kolab_util_calendar_create_http_request (KolabSettingsHandler *ksettings,
 	const gchar *passwd = NULL;
 	guint tls_variant = KOLAB_TLS_VARIANT_DEFAULT;
 	GError *tmp_error = NULL;
-	KolabHttpJob *job = NULL;
+	KolabUtilHttpJob *job = NULL;
 
 	g_assert (KOLAB_IS_SETTINGS_HANDLER (ksettings));
 	g_assert (path != NULL);
@@ -110,18 +107,18 @@ kolab_util_calendar_create_http_request (KolabSettingsHandler *ksettings,
 	         __func__);
 	/* camel_url_set_passwd (uri, passwd); */
 
-	job = kolab_http_job_new ();
+	job = kolab_util_http_job_new ();
 	job->url = uri;
 
 	return job;
 } /* kolab_util_calendar_create_http_request () */
 
-static KolabHttpJob*
+static KolabUtilHttpJob*
 kolab_util_calendar_create_pfb_trigger (KolabSettingsHandler *ksettings,
                                         const gchar *sourcename,
                                         GError **error)
 {
-	KolabHttpJob *job = NULL;
+	KolabUtilHttpJob *job = NULL;
 	gchar *path = NULL;
 	const gchar *username = NULL;
 	gint source_offset = 0;
@@ -155,12 +152,12 @@ kolab_util_calendar_create_pfb_trigger (KolabSettingsHandler *ksettings,
 	return job;
 } /* kolab_util_calendar_create_pfb_trigger () */
 
-static KolabHttpJob*
+static KolabUtilHttpJob*
 kolab_util_calendar_create_xfb_request (KolabSettingsHandler *ksettings,
                                         gchar *query,
                                         GError **error)
 {
-	KolabHttpJob *job = NULL;
+	KolabUtilHttpJob *job = NULL;
 	gchar *path = NULL;
 	GError *tmp_error = NULL;
 
@@ -243,7 +240,7 @@ kolab_util_calendar_toggle_pfb_trigger (KolabSettingsHandler *ksettings,
 	/* Keep running on errors.
 	 * If an error occured, internal_state is set to false as indicator.
 	 */
-	KolabHttpJob *job = NULL;
+	KolabUtilHttpJob *job = NULL;
 	GError *tmp_error = NULL;
 
 	g_assert (KOLAB_IS_SETTINGS_HANDLER (ksettings));
@@ -261,7 +258,7 @@ kolab_util_calendar_toggle_pfb_trigger (KolabSettingsHandler *ksettings,
 	}
 	job->buffer = g_byte_array_new ();
 	(void)kolab_util_http_get (job, &tmp_error);
-	kolab_http_job_free (job);
+	kolab_util_http_job_free (job);
 
 	if (tmp_error != NULL) {
 		g_propagate_error (error, tmp_error);
@@ -270,12 +267,12 @@ kolab_util_calendar_toggle_pfb_trigger (KolabSettingsHandler *ksettings,
 	return TRUE;
 } /* kolab_util_calendar_toggle_pfb_trigger () */
 
-KolabHttpJob*
+KolabUtilHttpJob*
 kolab_util_calendar_retrieve_xfb (KolabSettingsHandler *ksettings,
                                   gchar *query,
                                   GError **error)
 {
-	KolabHttpJob *job = NULL;
+	KolabUtilHttpJob *job = NULL;
 	GError *tmp_error = NULL;
 
 	g_assert (KOLAB_IS_SETTINGS_HANDLER (ksettings));
@@ -296,7 +293,7 @@ kolab_util_calendar_retrieve_xfb (KolabSettingsHandler *ksettings,
 	(void)kolab_util_http_get (job, &tmp_error);
 	if (tmp_error != NULL) {
 		/* might happen, perhaps the server did not now about the user. */
-		kolab_http_job_free (job);
+		kolab_util_http_job_free (job);
 		g_propagate_error (error, tmp_error);
 		return NULL;
 	}
