@@ -38,6 +38,8 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n-lib.h>
+
 #include <pk11func.h>
 #include <prtypes.h>
 
@@ -198,8 +200,7 @@ camel_kolab_session_bringup (CamelKolabSession *self,
 		g_set_error (err,
 		             KOLAB_CAMEL_KOLAB_ERROR,
 		             KOLAB_CAMEL_KOLAB_ERROR_GENERIC,
-		             "%s: data dir not configured",
-		             __func__);
+		             _("Camel data directory not configured"));
 		return FALSE;
 	}
 
