@@ -441,7 +441,7 @@ camel_imapx_extd_folder_new (CamelIMAPXExtdStore *store,
 	ifolder->cache = camel_data_cache_new (folder_dir, err);
 	if (!ifolder->cache) {
 		g_prefix_error (err,
-		                _("Could not create cache for %s: "),
+		                _("Could not create cache for %s"),
 		                short_name);
 		return NULL;
 	}
