@@ -1209,7 +1209,7 @@ imapx_extd_server_connect (CamelIMAPXServer *self,
 	g_return_val_if_fail (err == NULL || *err == NULL, FALSE);
 
 	if (self->state == IMAPX_SHUTDOWN) {
-		g_set_error (err, CAMEL_SERVICE_ERROR, CAMEL_SERVICE_ERROR_UNAVAILABLE, "Shutting down");
+		g_set_error (err, CAMEL_SERVICE_ERROR, CAMEL_SERVICE_ERROR_UNAVAILABLE, _("Shutting down"));
 		return FALSE;
 	}
 
