@@ -416,7 +416,7 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 	gtk_box_pack_start (GTK_BOX (kolab_vbox), GTK_WIDGET (hbox), TRUE, TRUE, 0);
 	spacer = gtk_label_new("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
-	tmp_str = g_strconcat (_("User Name"), ":", NULL);
+	tmp_str = g_strconcat (_("User ID"), ":", NULL);
 	label = gtk_label_new_with_mnemonic (tmp_str);
 	g_free (tmp_str);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -428,7 +428,7 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 	gtk_box_pack_start (GTK_BOX (kolab_vbox), GTK_WIDGET (hbox), TRUE, TRUE, 0);
 	spacer = gtk_label_new("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
-	tmp_str = g_strconcat (_("Server Folders"), ":", NULL);
+	tmp_str = g_strconcat (_("Server PIM-Folders"), ":", NULL);
 	label = gtk_label_new_with_mnemonic (tmp_str);
 	g_free (tmp_str);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
@@ -446,9 +446,9 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 	spacer = gtk_label_new("   ");
 	gtk_box_pack_start (GTK_BOX (hbox), spacer, FALSE, FALSE, 0);
 	if (widget_type == KOLAB_WIDGET_TYPE_CONTACT)
-		tmp_str = g_strconcat (_("Contact Folder"), ":", NULL);
+		tmp_str = g_strconcat (_("Selected Contact Folder"), ":", NULL);
 	else
-		tmp_str = g_strconcat (_("Calendar Folder"), ":", NULL);
+		tmp_str = g_strconcat (_("Selected Calendar Folder"), ":", NULL);
 	label = gtk_label_new_with_mnemonic (tmp_str);
 	g_free (tmp_str);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
