@@ -240,7 +240,7 @@ kolab_plugin_ui_get_selected_path (EShellView *shell_view,
 	return selected_path;
 }
 
-GtkWidget*
+static GtkWidget*
 kolab_plugin_ui_selected_folder_widget (GtkAction *action,
                                         EShellView *shell_view)
 {
@@ -281,7 +281,7 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 	uidata = kolab_folder_prop_ui_data_new ();
 
 	uidata->widgets->dialog = \
-		gtk_dialog_new_with_buttons (_("Edit Kolab folder properties..."),
+		gtk_dialog_new_with_buttons (_("Edit Kolab Folder Properties..."),
 		                             NULL, /* parent */
 		                             GTK_DIALOG_DESTROY_WITH_PARENT,
 		                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -317,7 +317,7 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 	                          NULL);
 	gtk_notebook_set_tab_label_text (notebook,
 	                                 uidata->meta_ui_data->widgets->container,
-	                                 _("Metadata"));
+	                                 _("IMAP Metadata"));
 
 	/* folder permissions notebook page */
 	gtk_notebook_append_page (notebook,
@@ -325,7 +325,7 @@ kolab_plugin_ui_action_kolab_properties_cb (GtkAction *action,
 	                          NULL);
 	gtk_notebook_set_tab_label_text (notebook,
 	                                 uidata->perm_ui_data->widgets->container,
-	                                 _("Access Control"));
+	                                 _("IMAP Access Control"));
 
 	/* TODO connect signals */
 
