@@ -25,6 +25,10 @@
 
 /*----------------------------------------------------------------------------*/
 
+#include <config.h>
+
+#include <glib/gi18n-lib.h>
+
 #include <libekolabutil/kolab-util-folder.h>
 #include <libekolabutil/kolab-util-kconv.h>
 
@@ -171,8 +175,8 @@ kolab_mail_handle_check_complete (const KolabMailHandle *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_INTERNAL,
-		             "%s: UID (%s) Folder (%s) summary consistency check failed",
-		             function_name, priv->kolab_uid, priv->foldername);
+		             _("Internal inconsistency detected: PIM Object handle has inconsistent summary information, UID '%s', Folder '%s'"),
+		             priv->kolab_uid, priv->foldername);
 		return FALSE;
 	}
 
@@ -182,8 +186,8 @@ kolab_mail_handle_check_complete (const KolabMailHandle *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_CONTEXT_MISUSE,
-		             "%s: UID (%s) Folder (%s) context error: expected KolabFolderContextID %i, got %i",
-		             function_name, priv->kolab_uid, priv->foldername, context, folder_context);
+		             _("Internal inconsistency detected: PIM Object handle has inconsistent folder context information (expected %i, got %i), UID '%s', Folder '%s'"),
+		             context, folder_context, priv->kolab_uid, priv->foldername);
 		return FALSE;
 	}
 
@@ -193,8 +197,8 @@ kolab_mail_handle_check_complete (const KolabMailHandle *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_HANDLE_INCOMPLETE,
-		             "%s: UID (%s) Folder (%s) KolabMailHandle is still incomplete",
-		             function_name, priv->kolab_uid, priv->foldername);
+		             _("Internal inconsistency detected: PIM Object handle is incomplete, UID '%s', Folder '%s'"),
+		             priv->kolab_uid, priv->foldername);
 		return FALSE;
 	}
 
@@ -407,8 +411,8 @@ kolab_mail_handle_convert_eds_to_kconvmail (KolabMailHandle *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_KOLAB,
-		             "%s: UID (%s) Folder (%s) conversion to Kolab format failed",
-		             __func__, priv->kolab_uid, priv->foldername);
+		             _("Data conversion to Kolab format failed for PIM Object, UID '%s', Folder '%s'"),
+		             priv->kolab_uid, priv->foldername);
 		return FALSE;
 	}
 
@@ -489,15 +493,15 @@ kolab_mail_handle_convert_kconvmail_to_eds (KolabMailHandle *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_KOLAB,
-		             "%s: UID (%s) Folder (%s) JOURNAL data type not supported",
-		             __func__, priv->kolab_uid, priv->foldername);
+		             _("JOURNAL data type not supported for PIM Object, UID '%s', Folder '%s'"),
+		             priv->kolab_uid, priv->foldername);
 		return FALSE;
 	default:
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_KOLAB,
-		             "%s: UID (%s) Folder (%s) unknown data type, not supported",
-		             __func__, priv->kolab_uid, priv->foldername);
+		             _("Unknown data type for PIM Object, UID '%s', Folder '%s'"),
+		             priv->kolab_uid, priv->foldername);
 		return FALSE;
 	}
 
@@ -527,16 +531,16 @@ kolab_mail_handle_convert_kconvmail_to_eds (KolabMailHandle *self,
 			g_set_error (err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_DATATYPE_KOLAB,
-			             "%s: UID (%s) Folder (%s) conversion from Kolab calendar type failed",
-			             __func__, priv->kolab_uid, priv->foldername);
+			             _("Conversion from Kolab calendar type to Evolution failed for PIM Object, UID '%s', Folder '%s'"),
+			             priv->kolab_uid, priv->foldername);
 			return FALSE;
 		}
 		if (calcomptz->maincomp == NULL) {
 			g_set_error (err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_DATATYPE_KOLAB,
-			             "%s: UID (%s) Folder (%s) got ECalComponentWithTZ with NULL maincomp member",
-			             __func__, priv->kolab_uid, priv->foldername);
+			             _("Internal inconsistency detected: Corrupt timezone object for PIM Object, UID '%s', Folder '%s'"),
+			             priv->kolab_uid, priv->foldername);
 			return FALSE;
 		}
 		e_cal_component_get_uid (calcomptz->maincomp, &component_uid);
@@ -547,8 +551,8 @@ kolab_mail_handle_convert_kconvmail_to_eds (KolabMailHandle *self,
 			g_set_error (err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_DATATYPE_KOLAB,
-			             "%s: UID (%s) Folder (%s) invalid Kolab mail (UID in subject does not match UID in data part)",
-			             __func__, priv->kolab_uid, priv->foldername);
+			             _("Invalid Kolab mail object (UID in subject does not match UID in data part), UID '%s', Folder '%s'"),
+			             priv->kolab_uid, priv->foldername);
 			return FALSE;
 		}
 		/* KolabMailSummary */
@@ -560,8 +564,8 @@ kolab_mail_handle_convert_kconvmail_to_eds (KolabMailHandle *self,
 			g_set_error (err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_DATATYPE_KOLAB,
-			             "%s: UID (%s) Folder (%s) conversion from Kolab contact type failed",
-			             __func__, priv->kolab_uid, priv->foldername);
+			             "Conversion from Kolab contact type to Evolution failed for PIM Object, UID '%s', Folder '%s'",
+			             priv->kolab_uid, priv->foldername);
 			return FALSE;
 		}
 		contact_uid = e_contact_get (econtact, E_CONTACT_UID);
@@ -573,8 +577,8 @@ kolab_mail_handle_convert_kconvmail_to_eds (KolabMailHandle *self,
 			g_set_error (err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_DATATYPE_KOLAB,
-			             "%s: UID (%s) Folder (%s) invalid Kolab mail (UID in subject does not match UID in data part)",
-			             __func__, priv->kolab_uid, priv->foldername);
+			             _("Invalid Kolab mail object (UID in subject does not match UID in data part), UID '%s', Folder '%s'"),
+			             priv->kolab_uid, priv->foldername);
 			return FALSE;
 		}
 		g_free (contact_uid);
@@ -598,8 +602,8 @@ kolab_mail_handle_convert_kconvmail_to_eds (KolabMailHandle *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_INTERNAL,
-		             "%s: UID (%s) Folder (%s) invalid KolabMailSummary",
-		             __func__, priv->kolab_uid, priv->foldername);
+		             _("Internal inconsistency detected: Invalid summary information for PIM Object, UID '%s', Folder '%s'"),
+		             priv->kolab_uid, priv->foldername);
 		return FALSE;
 	}
 
@@ -875,8 +879,8 @@ kolab_mail_handle_set_summary (KolabMailHandle *self,
 			g_set_error (err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_INTERNAL,
-			             "%s: UID (%s) Folder (%s) summary inconsistent, taking no action",
-			             __func__, priv->kolab_uid, priv->foldername);
+			             _("Internal inconsistency detected: Invalid summary information for PIM Object, UID '%s', Folder '%s'"),
+			             priv->kolab_uid, priv->foldername);
 			return FALSE;
 		}
 	}
