@@ -25,6 +25,10 @@
 
 /*----------------------------------------------------------------------------*/
 
+#include <config.h>
+
+#include <glib/gi18n-lib.h>
+
 #include <camel/camel-kolab-imapx-provider.h>
 #include <camel/camel-kolab-imapx-store.h>
 #include <camel/camel-kolab-imapx-folder.h>
@@ -224,8 +228,8 @@ kolab_mail_imap_client_camel_get_folder (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_CAMEL_ERROR,
 		             KOLAB_CAMEL_ERROR_GENERIC,
-		             "%s: cannot get folder for (%s): %s",
-		             __func__, foldername, "NULL folder");
+		             _("Cannot get Camel folder for path '%s'"),
+		             foldername);
 		return NULL;
 	}
 
@@ -681,8 +685,7 @@ kolab_mail_imap_client_configure (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_GENERIC,
-		             "%s: folder context not set on settings handler",
-		             __func__);
+		             _("Internal inconsistency detected: Folder PIM context not set"));
 		return FALSE;
 	}
 
@@ -780,8 +783,7 @@ kolab_mail_imap_client_bringup (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "%s: need server name to be set",
-		             __func__);
+		             _("Internal inconsistency detected: Kolab server name not set"));
 		return FALSE;
 
 	}
@@ -799,7 +801,7 @@ kolab_mail_imap_client_bringup (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "%s: need user name to be set",
+		             _("Internal inconsistency detected: Kolab User ID not set"));
 		             __func__);
 		return FALSE;
 
@@ -851,8 +853,8 @@ kolab_mail_imap_client_bringup (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_CAMEL,
-		             "%s: could not get service for protocol %s",
-		             __func__, KOLAB_CAMEL_PROVIDER_PROTOCOL);
+		             _("Could not get a Camel service for protocol '%s'"),
+		             KOLAB_CAMEL_PROVIDER_PROTOCOL);
 		return FALSE;
 	}
 #endif
@@ -863,8 +865,8 @@ kolab_mail_imap_client_bringup (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_CAMEL,
-		             "%s: could not set context [%i] on store",
-		             __func__, priv->context);
+		             _("Could not set PIM folder context %i for this backend"),
+		             priv->context);
 		return FALSE;
 	}
 
@@ -1165,8 +1167,8 @@ kolab_mail_imap_client_get_folder_type (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_CAMEL_ERROR,
 		             KOLAB_CAMEL_ERROR_GENERIC,
-		             "%s: invalid folder type for (%s)",
-		             __func__, foldername);
+		             _("Folder '%s' has an invalid PIM type"),
+		             foldername);
 		return KOLAB_FOLDER_TYPE_INVAL;
 	}
 
@@ -1408,8 +1410,8 @@ kolab_mail_imap_client_query_summaries (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_CONTEXT_MISUSE,
-		             "%s: folder type does not map to folder context for (%s)",
-		             __func__, foldername);
+		             _("Internal inconsistency detected: Folder '%s' has a PIM type %i set which does not map to a known folder context"),
+		             foldername, foldertype);
 		return NULL;
 	}
 
@@ -1484,8 +1486,7 @@ kolab_mail_imap_client_store (KolabMailImapClient *self,
 		g_set_error (&tmp_err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "%s: folder creation not yet implemented",
-		             __func__);
+		             _("Folder creation not yet implemented"));
 		goto cleanup;
 	}
 
@@ -1498,8 +1499,7 @@ kolab_mail_imap_client_store (KolabMailImapClient *self,
 			g_set_error (&tmp_err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_INTERNAL,
-			             "%s: moving object to different folder not yet implemented",
-			             __func__);
+			             _("Moving object to different folder not yet implemented"));
 			goto cleanup;
 		}
 	}
@@ -1526,8 +1526,8 @@ kolab_mail_imap_client_store (KolabMailImapClient *self,
 		g_set_error (&tmp_err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             "%s: could not get CamelFolder for (%s)",
-		             __func__, foldername);
+		             _("Could not get Camel folder for '%s'"),
+		             foldername);
 		goto cleanup;
 	}
 
@@ -1635,8 +1635,8 @@ kolab_mail_imap_client_store (KolabMailImapClient *self,
 		g_set_error (&tmp_err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_CAMEL,
-		             "%s: UID (%s) Folder (%s) could not read-back message from server",
-		             __func__, kolab_uid, foldername);
+		             _("Could not read-back mail message from server, UID '%s', Folder '%s'"),
+		             kolab_uid, foldername);
 		goto cleanup;
 	}
 
@@ -1646,8 +1646,8 @@ kolab_mail_imap_client_store (KolabMailImapClient *self,
 		g_set_error (&tmp_err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "%s: UID (%s) Folder (%s) could not get IMAP UID from message",
-		             __func__, kolab_uid, foldername);
+		             _("Could not get IMAP UID from message, UID '%s', Folder '%s'"),
+		             kolab_uid, foldername);
 		goto cleanup;
 	}
 
@@ -1752,8 +1752,7 @@ kolab_mail_imap_client_retrieve (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "%s: Kolab UID not set on handle!",
-		             __func__);
+		             _("Internal inconsistency detected: Kolab UID not set on PIM Object handle"));
 		return FALSE;
 	}
 
@@ -1762,8 +1761,8 @@ kolab_mail_imap_client_retrieve (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "%s: UID (%s) foldername not set",
-		             __func__, kolab_uid);
+		             _("Internal inconsistency detected: Folder name not set on PIM Object handle, UID '%s'"),
+		             kolab_uid);
 		return FALSE;
 	}
 
@@ -1789,8 +1788,8 @@ kolab_mail_imap_client_retrieve (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_INTERNAL,
-		             "%s: UID (%s) folder context mismatch, (%i) (real) vs. (%i) (stored)",
-		             __func__, kolab_uid, context, s_context);
+		             _("Internal inconsistency detected: Folder context mismatch, real is %i, stored is %i, UID '%s', Folder '%s'"),
+		             context, s_context, kolab_uid, foldername);
 		return FALSE;
 	}
 
@@ -1844,8 +1843,8 @@ kolab_mail_imap_client_retrieve (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             "%s: could not find Kolab UID (%s) in folder (%s)",
-		             __func__, kolab_uid, foldername);
+		             _("Could not find Kolab mail message, UID '%s', Folder '%s'"),
+		             kolab_uid, foldername);
 		return FALSE;
 	}
 
@@ -1911,8 +1910,7 @@ kolab_mail_imap_client_delete (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "%s: Kolab UID not set on handle!",
-		             __func__);
+		             _("Internal inconsistency detected: Kolab UID not set on PIM Object handle"));
 		return FALSE;
 	}
 
@@ -1921,8 +1919,8 @@ kolab_mail_imap_client_delete (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INTERNAL,
-		             "%s: UID (%s) foldername not set",
-		             __func__, kolab_uid);
+		             _("Internal inconsistency detected: Folder name not set on PIM Object handle, UID '%s'"),
+		             kolab_uid);
 		return FALSE;
 	}
 
@@ -1951,8 +1949,8 @@ kolab_mail_imap_client_delete (KolabMailImapClient *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             "%s: could not get CamelFolder for (%s)",
-		             __func__, foldername);
+		             _("Could not get Camel folder for '%s'"),
+		             foldername);
 		return FALSE;
 	}
 
