@@ -39,9 +39,13 @@
 
 /*----------------------------------------------------------------------------*/
 
+#include <config.h>
+
 #include <string.h>
 #include <sqlite3.h>
 
+#include <glib/gi18n-lib.h>
+
 #include <libekolabutil/kolab-util-glib.h>
 #include <libekolabutil/kolab-util-sqlite.h>
 #include <libekolabutil/kolab-util-error.h>
@@ -499,8 +503,8 @@ kolab_mail_info_db_sql_query_folder (KolabUtilSqliteDb *kdb,
 			g_set_error (err,
 			             KOLAB_UTIL_ERROR,
 			             KOLAB_UTIL_ERROR_SQLITE_DB,
-			             "%s: %s",
-			             __func__, sqlite3_errmsg (kdb->db));
+			             _("SQLite Error: %s"),
+			             sqlite3_errmsg (kdb->db));
 		}
 		(void)kolab_util_sqlite_fnlz_stmt (kdb, sql_stmt, NULL);
 		return NULL;
@@ -633,8 +637,8 @@ kolab_mail_info_db_sql_query_record (KolabUtilSqliteDb *kdb,
 			g_set_error (err,
 			             KOLAB_UTIL_ERROR,
 			             KOLAB_UTIL_ERROR_SQLITE_DB,
-			             "%s: %s",
-			             __func__, sqlite3_errmsg (kdb->db));
+			             _("SQLite Error: %s"),
+			             sqlite3_errmsg (kdb->db));
 		}
 		(void)kolab_util_sqlite_fnlz_stmt (kdb, sql_stmt, NULL);
 		g_free (tblname);
@@ -963,8 +967,8 @@ kolab_mail_info_db_query_uids (KolabMailInfoDb *self,
 				g_set_error (&tmp_err,
 				             KOLAB_UTIL_ERROR,
 				             KOLAB_UTIL_ERROR_SQLITE_DB,
-				             "%s: %s",
-				             __func__, sqlite3_errmsg (priv->kdb->db));
+				             _("SQLite Error: %s"),
+				             sqlite3_errmsg (priv->kdb->db));
 			}
 			break;
 		}
@@ -1088,8 +1092,8 @@ kolab_mail_info_db_query_changed_uids (KolabMailInfoDb *self,
 				g_set_error (&tmp_err,
 				             KOLAB_UTIL_ERROR,
 				             KOLAB_UTIL_ERROR_SQLITE_DB,
-				             "%s: %s",
-				             __func__, sqlite3_errmsg (priv->kdb->db));
+				             _("SQLite Error: %s"),
+				             sqlite3_errmsg (priv->kdb->db));
 			}
 			break;
 		}
@@ -1226,8 +1230,8 @@ kolab_mail_info_db_query_foldernames (KolabMailInfoDb *self,
 				g_set_error (&tmp_err,
 				             KOLAB_UTIL_ERROR,
 				             KOLAB_UTIL_ERROR_SQLITE_DB,
-				             "%s: %s",
-				             __func__, sqlite3_errmsg (priv->kdb->db));
+				             _("SQLite Error: %s"),
+				             sqlite3_errmsg (priv->kdb->db));
 			}
 			break;
 		}
@@ -1352,8 +1356,8 @@ kolab_mail_info_db_query_folder_summary (KolabMailInfoDb *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             "%s: Folder (%s) not known to InfoDb",
-		             __func__, foldername);
+		             _("Folder name not known to internal database: '%s'"),
+		             foldername);
 		return NULL;
 	}
 
@@ -1444,8 +1448,8 @@ kolab_mail_info_db_remove_folder (KolabMailInfoDb *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             "%s: Folder name to be removed does not exist: [%s]",
-		             __func__, foldername);
+		             _("Folder to be removed does not exist in internal database: '%s'"),
+		             foldername);
 		return FALSE;
 	}
 
@@ -1593,8 +1597,8 @@ kolab_mail_info_db_query_record (KolabMailInfoDb *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_INTERNAL,
-		             "%s: UID (%s) Folder (%s) without folder summary",
-		             __func__, uid, foldername);
+		             _("Internal inconsistency detected: Folder without summary information, UID '%s', Folder '%s'"),
+		             uid, foldername);
 		kolab_mail_info_db_record_free (record);
 		return NULL;
 	}
@@ -1606,8 +1610,8 @@ kolab_mail_info_db_query_record (KolabMailInfoDb *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_INTERNAL,
-		             "%s: UID (%s) has it's folder deleted: (%s)",
-		             __func__, uid, foldername);
+		             _("Internal inconsistency detected: PIM Object has its folder deleted, UID '%s', Folder '%s'"),
+		             uid, foldername);
 		kolab_mail_info_db_record_free (record);
 		return NULL;
 	}
@@ -1657,8 +1661,8 @@ kolab_mail_info_db_update_record (KolabMailInfoDb *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INFODB_NOFOLDER,
-		             "%s: Unknown folder name: (%s)",
-		             __func__, foldername);
+		             _("Folder name not known to internal database: '%s'"),
+		             foldername);
 		return FALSE;
 	}
 
@@ -1672,8 +1676,8 @@ kolab_mail_info_db_update_record (KolabMailInfoDb *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_INFODB_NOFOLDER,
-		             "%s: Destination folder has been deleted: (%s)",
-		             __func__, foldername);
+		             _("Destination folder has been deleted: '%s'"),
+		             foldername);
 		return FALSE;
 	}
 
@@ -1733,8 +1737,8 @@ kolab_mail_info_db_remove_record (KolabMailInfoDb *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             "%s: UID (%s) Folder (%s) not found in records DB",
-		             __func__, uid, foldername);
+		             _("Record missing in internal database, UID '%s', Folder '%s'"),
+		             uid, foldername);
 		return FALSE;
 	}
 
