@@ -25,8 +25,12 @@
 
 /*----------------------------------------------------------------------------*/
 
+#include <config.h>
+
 #include <string.h>
 
+#include <glib/gi18n-lib.h>
+
 #include "kolab-util-backend.h"
 #include "kolab-mail-mime-builder.h"
 
@@ -224,8 +228,7 @@ kolab_mail_mime_builder_conv_new_from_camel (KolabMailMimeBuilder *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_CAMEL,
-		             "%s: cannot unpack CamelMimeMessage",
-		             __func__);
+		             _("Cannot unpack Camel mime message"));
 		return NULL;
 	}
 
@@ -233,8 +236,7 @@ kolab_mail_mime_builder_conv_new_from_camel (KolabMailMimeBuilder *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_CAMEL,
-		             "%s: no multipart message, ignoring",
-		             __func__);
+		             _("Mail message is not a multipart message, ignoring"));
 		/* need to unref data wrapper? */
 		return NULL;
 	}
@@ -248,8 +250,8 @@ kolab_mail_mime_builder_conv_new_from_camel (KolabMailMimeBuilder *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_DATATYPE_KOLAB,
-		             "%s: at least %i mime parts expected, skipping message",
-		             __func__, KOLAB_MAIL_MIME_PARTS_MIN);
+		             _("Mail message does not have the expected minimum of %i mime parts, ignoring"),
+		             KOLAB_MAIL_MIME_PARTS_MIN);
 		return NULL;
 	}
 
@@ -286,8 +288,7 @@ kolab_mail_mime_builder_conv_new_from_camel (KolabMailMimeBuilder *self,
 			g_set_error (&tmp_err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_CAMEL,
-			             "%s: NULL content type, skipping mime part",
-			             __func__);
+			             _("Mail message mime part has no content type set, skipping"));
 			goto mime_part_cleanup;
 		}
 		if (name == NULL) {
@@ -299,8 +300,7 @@ kolab_mail_mime_builder_conv_new_from_camel (KolabMailMimeBuilder *self,
 			g_set_error (&tmp_err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_CAMEL,
-			             "%s: could not get data wrapper for mime part, skipping",
-			             __func__);
+			             _("Could not get Camel data wrapper for mime part, skipping"));
 			goto mime_part_cleanup;
 		}
 
@@ -463,8 +463,7 @@ kolab_mail_mime_builder_camel_new_from_conv (KolabMailMimeBuilder *self,
 			g_set_error (&tmp_err,
 			             KOLAB_BACKEND_ERROR,
 			             KOLAB_BACKEND_ERROR_INTERNAL,
-			             "%s: invalid Kolabconv_mail_part, no CamelMimeMessage created",
-			             __func__);
+			             _("Internal inconsistency detected: Invaldid mail part after Kolab data conversion, no Camel message created"));
 			goto mime_part_skip;
 		}
 
