@@ -25,8 +25,12 @@
 
 /*----------------------------------------------------------------------------*/
 
+#include <config.h>
+
 #include <errno.h>
 
+#include <glib/gi18n-lib.h>
+
 #include <libekolabutil/kolab-util-glib.h>
 
 #include "kolab-util-backend.h"
@@ -150,8 +154,8 @@ kolab_settings_handler_char_get_func_camel_data_dir (KolabSettingsHandler *self,
 		g_set_error (err,
 		             G_FILE_ERROR,
 		             g_file_error_from_errno (errno),
-		             "%s: could not create directory %s: %s",
-		             __func__, data_dir, g_strerror (errno));
+		             _("Could not create directory '%s' ('%s')"),
+		             data_dir, g_strerror (errno));
 		g_free (data_dir);
 		return FALSE;
 	}
@@ -168,8 +172,7 @@ kolab_settings_handler_char_set_func_camel_data_dir (KolabSettingsHandler *self,
 	g_set_error (err,
 	             KOLAB_BACKEND_ERROR,
 	             KOLAB_BACKEND_ERROR_GENERIC,
-	             "%s: camel data dir cannot be set",
-	             __func__);
+	             _("Cannot set Camel data directory, it is a read-only resource"));
 	return FALSE;
 }
 
@@ -201,8 +204,8 @@ kolab_settings_handler_char_get_func_camel_config_dir (KolabSettingsHandler *sel
 		g_set_error (err,
 		             G_FILE_ERROR,
 		             g_file_error_from_errno (errno),
-		             "%s: could not create directory %s: %s",
-		             __func__, config_dir, g_strerror (errno));
+		             _("Could not create directory '%s' ('%s')"),
+		             config_dir, g_strerror (errno));
 		g_free (config_dir);
 		return FALSE;
 	}
@@ -219,8 +222,7 @@ kolab_settings_handler_char_set_func_camel_config_dir (KolabSettingsHandler *sel
 	g_set_error (err,
 	             KOLAB_BACKEND_ERROR,
 	             KOLAB_BACKEND_ERROR_GENERIC,
-	             "%s: camel config dir cannot be set",
-	             __func__);
+	             _("Cannot set Camel configuration directory, it is a read-only resource"));
 	return FALSE;
 }
 
@@ -232,8 +234,7 @@ kolab_settings_handler_uint_set_func_folder_context (KolabSettingsHandler *self,
 	g_set_error (err,
 	             KOLAB_BACKEND_ERROR,
 	             KOLAB_BACKEND_ERROR_GENERIC,
-	             "%s: folder context cannot be re-set after configuration",
-	             __func__);
+	             _("Cannot change folder context after it has initially been set"));
 	return FALSE;
 }
 
@@ -879,8 +880,7 @@ kolab_settings_handler_get_value (KolabSettingsHandler *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             "%s: no internal table, no value has ever been set",
-		             __func__);
+		             _("Internal inconsistency detected: No settings table exists, no value has previously been set"));
 		return NULL;
 	}
 
@@ -890,8 +890,8 @@ kolab_settings_handler_get_value (KolabSettingsHandler *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             "%s: no table with id (%i) exists",
-		             __func__, tbl_id);
+		             _("Internal inconsistency detected: No settings table with ID '%i' exists"),
+		             tbl_id);
 		return NULL;
 	}
 
@@ -900,8 +900,8 @@ kolab_settings_handler_get_value (KolabSettingsHandler *self,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_NOTFOUND,
-		             "%s: no value for table id (%i) key (%s) exists",
-		             __func__, tbl_id, key);
+		             _("Internal inconsistency detected: No settings value for table ID '%i', key ID '%s', exists"),
+		             tbl_id, key);
 		return NULL;
 	}
 
