@@ -404,8 +404,7 @@ kolab_util_backend_sqlite_db_new_open (KolabUtilSqliteDb **kdb,
 		g_set_error (err,
 		             KOLAB_BACKEND_ERROR,
 		             KOLAB_BACKEND_ERROR_CAMEL,
-		             "%s: could not get Camel storage path for InfoDb",
-		             __func__);
+		             _("Could not get Camel storage path for internal database"));
 		return FALSE;
 	}
 	*kdb = kolab_util_sqlite_db_new ();
