@@ -23,6 +23,10 @@
  * 51 Franklin Street, Fifth Floor Boston, MA 02110-1301, USA
  */
 
+#include <config.h>
+
+#include <glib/gi18n-lib.h>
+
 #include <libecal/e-cal-util.h>
 #include "kolab-conv.h"
 #include "evolution/evolution.h"
@@ -178,7 +182,7 @@ kolabconv_cal_util_freebusy_ecalcomp_new_from_ics (const gchar *ics_string,
 		g_set_error (err,
 			     KOLABCONV_ERROR_READ_KOLAB,
 			     KOLABCONV_ERROR_READ_KOLAB_INPUT_IS_NULL, /* appropriate? */
-		             "empty server response");
+		             _("Empty server response"));
 		goto CLEANUP;
 	}
 
@@ -189,7 +193,7 @@ kolabconv_cal_util_freebusy_ecalcomp_new_from_ics (const gchar *ics_string,
 		g_set_error (err,
 			     KOLABCONV_ERROR_READ_KOLAB,
 			     KOLABCONV_ERROR_READ_KOLAB_MALFORMED_XML, /* appropriate? */
-		             "cannot parse server response");
+		             _("Cannot parse server response"));
 		goto CLEANUP;
 	}
 
@@ -206,7 +210,7 @@ kolabconv_cal_util_freebusy_ecalcomp_new_from_ics (const gchar *ics_string,
 			g_set_error (err,
 			             KOLABCONV_ERROR_READ_KOLAB,
 			             KOLABCONV_ERROR_READ_KOLAB_INVALID_KOLAB_XML, /* appropriate? */
-			             "unsupported component type");
+			             _("Unsupported component type"));
 		}
 		g_object_unref (ecalcomp_tmp);
 		ecalcomp_tmp = NULL;
@@ -215,7 +219,7 @@ kolabconv_cal_util_freebusy_ecalcomp_new_from_ics (const gchar *ics_string,
 		g_set_error (err,
 			     KOLABCONV_ERROR_READ_KOLAB,
 			     KOLABCONV_ERROR_READ_KOLAB_MISSING_XML_PART, /* appropriate? */
-			     "unsupported component type");
+		             _("Unsupported component type"));
 	}
 
 CLEANUP:
