@@ -32,6 +32,10 @@
  * The related header file is: kolab.h
  */
 
+#include <config.h>
+
+#include <glib/gi18n-lib.h>
+
 #include "priv-kolab.h"
 #include "kolab.h" /* public part of this file */
 #include "../util.h"
@@ -90,9 +94,9 @@ conv_kolab_conv_mail_to_I_contact (const Kolab_conv_mail* k_contact, GError** er
 				g_strcmp0((gchar*)n_ptr->name, KLB_CNT) == 0)
 			node = n_ptr;
 	if (node == NULL) {
-		g_set_error(error, KOLABCONV_ERROR_READ_KOLAB,
-				KOLABCONV_ERROR_READ_KOLAB_INVALID_KOLAB_XML,
-				"root tag is missing");
+		g_set_error (error, KOLABCONV_ERROR_READ_KOLAB,
+		             KOLABCONV_ERROR_READ_KOLAB_INVALID_KOLAB_XML,
+		             _("Root tag is missing"));
 		free_i_contact (&i_contact);
 		xmlFreeDoc(doc);
 		return NULL;
