@@ -25,6 +25,10 @@
 
 #define _XOPEN_SOURCE 600 /* glibc2 needs this */
 
+#include <config.h>
+
+#include <glib/gi18n-lib.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
@@ -140,9 +144,9 @@ util_get_kolab_xml_part(const Kolab_conv_mail *klb_mail, GList **other_parts, GE
 
 	/* check input paramters */
 	if (klb_mail == NULL) {
-		g_set_error(error, KOLABCONV_ERROR_READ_KOLAB,
-				KOLABCONV_ERROR_READ_KOLAB_INPUT_IS_NULL,
-				"kolab mail struct must not be null");
+		g_set_error (error, KOLABCONV_ERROR_READ_KOLAB,
+		             KOLABCONV_ERROR_READ_KOLAB_INPUT_IS_NULL,
+		             _("Kolab mail struct must not be null"));
 		return NULL;
 	}
 	/* iterate over mail parts, search kolab xml part, parse and return it */
@@ -152,18 +156,18 @@ util_get_kolab_xml_part(const Kolab_conv_mail *klb_mail, GList **other_parts, GE
 			/* found kolab xml part => parse it in memory */
 			doc = xmlReadMemory (mail_part->data, (int) mail_part->length, NULL, NULL, 0);
 			if (doc == NULL) {
-				g_set_error(error, KOLABCONV_ERROR_READ_KOLAB,
-						KOLABCONV_ERROR_READ_KOLAB_MALFORMED_XML,
-						"xml parser returned null for data part %d", i);
+				g_set_error (error, KOLABCONV_ERROR_READ_KOLAB,
+				             KOLABCONV_ERROR_READ_KOLAB_MALFORMED_XML,
+				             _("XML parser returned null for data part %d"), i);
 				return NULL;
 			}
 		} else /* part must be cloned here because it will be freed when converting from internal */
 			*other_parts = g_list_append(*other_parts, clone_kolab_conv_mail_part(mail_part));
 	}
 	if (doc == NULL) /* no kolab xml part could be found */
-		g_set_error(error, KOLABCONV_ERROR_READ_KOLAB,
-			KOLABCONV_ERROR_READ_KOLAB_MISSING_XML_PART,
-			"kolab mail struct has no kolab xml data part");
+		g_set_error (error, KOLABCONV_ERROR_READ_KOLAB,
+		             KOLABCONV_ERROR_READ_KOLAB_MISSING_XML_PART,
+		             _("Kolab mail struct has no Kolab XML data part"));
 
 	return doc;
 }
