@@ -25,6 +25,10 @@
 
 /*----------------------------------------------------------------------------*/
 
+#include <config.h>
+
+#include <glib/gi18n-lib.h>
+
 #include <e-util/e-util.h>
 
 #include "camel-system-headers.h"
@@ -53,8 +57,7 @@ kolab_util_camel_init (GError **err)
 		g_set_error (err,
 			     KOLAB_CAMEL_ERROR,
 			     KOLAB_CAMEL_ERROR_GENERIC,
-			     "%s: failed to init camel subsystem",
-			     __func__);
+		             _("Failed to initialize Camel subsystem"));
 		return FALSE;
 	}
 
@@ -125,9 +128,7 @@ kolab_util_camel_get_storage_path (CamelService *service,
 		g_set_error (err,
 			     KOLAB_CAMEL_KOLAB_ERROR,
 			     KOLAB_CAMEL_KOLAB_ERROR_DB,
-			     "%s: could get Camel storage path",
-			     __func__);
-
+		             _("Could not get Camel storage path"));
 	}
 #endif
 
