@@ -50,7 +50,10 @@
 
 /*----------------------------------------------------------------------------*/
 
+#include <config.h>
+
 #include <glib.h>
+#include <glib/gi18n-lib.h>
 
 #include <camel/camel-kolab-stream.h>
 
@@ -214,7 +217,8 @@ kolab_util_http_soup_get (const KolabUtilHttpJob *job, GError **error)
 		g_set_error (error,
 		             KOLAB_UTIL_HTTP_ERROR,
 		             error_code,
-		             "libsoup failed with status %u", status);
+		             _("Libsoup failed with status %u"),
+		             status);
 	}
 
 	return nbytes;
@@ -374,7 +378,8 @@ kolab_util_http_curl_get (KolabUtilHttpJob *job, GError **error)
 		g_set_error (error,
 		             KOLAB_UTIL_HTTP_ERROR,
 		             KOLAB_UTIL_HTTP_ERROR_CONFIGURATION_ERROR,
-		             "Configuring libcurl failed with CURLcode: %u.", curlcode);
+		             _("Configuring libcurl failed with CURLcode: %u"),
+		             curlcode);
 		return -1;
 	}
 
@@ -395,7 +400,7 @@ kolab_util_http_curl_get (KolabUtilHttpJob *job, GError **error)
 		g_set_error (error,
 		             KOLAB_UTIL_HTTP_ERROR,
 		             error_code,
-		             "Access to %s failed in libcurl with CURLcode: %u",
+		             _("Access to URL '%s' failed in libcurl with CURLcode: %u"),
 		             camel_url_to_string (job->url, CAMEL_URL_HIDE_AUTH), curlcode);
 	}
 	else {
